==> knative-model-6.7.1-sources.jar: io/fabric8/knative/eventing/contrib/github/v1alpha1/SecretValueFromSourceBuilder.java <==
package io.fabric8.knative.eventing.contrib.github.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SecretValueFromSourceBuilder extends SecretValueFromSourceFluentImpl<SecretValueFromSourceBuilder> implements VisitableBuilder<SecretValueFromSource,SecretValueFromSourceBuilder>{
  public SecretValueFromSourceBuilder() {
    this(false);
  }
  public SecretValueFromSourceBuilder(Boolean validationEnabled) {
    this(new SecretValueFromSource(), validationEnabled);
  }
  public SecretValueFromSourceBuilder(SecretValueFromSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public SecretValueFromSourceBuilder(SecretValueFromSourceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SecretValueFromSource(), validationEnabled);
  }
  public SecretValueFromSourceBuilder(SecretValueFromSourceFluent<?> fluent,SecretValueFromSource instance) {
    this(fluent, instance, false);
  }
  public SecretValueFromSourceBuilder(SecretValueFromSourceFluent<?> fluent,SecretValueFromSource instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withSecretKeyRef(instance.getSecretKeyRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  public SecretValueFromSourceBuilder(SecretValueFromSource instance) {
    this(instance,false);
  }
  public SecretValueFromSourceBuilder(SecretValueFromSource instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withSecretKeyRef(instance.getSecretKeyRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  SecretValueFromSourceFluent<?> fluent;
  Boolean validationEnabled;
  public SecretValueFromSource build() {
    SecretValueFromSource buildable = new SecretValueFromSource(fluent.getSecretKeyRef());
    return buildable;
  }
  
}

==> knative-model-6.8.0-sources.jar: io/fabric8/knative/eventing/contrib/github/v1alpha1/SecretValueFromSourceBuilder.java <==
package io.fabric8.knative.eventing.contrib.github.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SecretValueFromSourceBuilder extends SecretValueFromSourceFluent<SecretValueFromSourceBuilder> implements VisitableBuilder<SecretValueFromSource,SecretValueFromSourceBuilder>{
  public SecretValueFromSourceBuilder() {
    this(false);
  }
  public SecretValueFromSourceBuilder(Boolean validationEnabled) {
    this(new SecretValueFromSource(), validationEnabled);
  }
  public SecretValueFromSourceBuilder(SecretValueFromSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public SecretValueFromSourceBuilder(SecretValueFromSourceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SecretValueFromSource(), validationEnabled);
  }
  public SecretValueFromSourceBuilder(SecretValueFromSourceFluent<?> fluent,SecretValueFromSource instance) {
    this(fluent, instance, false);
  }
  public SecretValueFromSourceBuilder(SecretValueFromSourceFluent<?> fluent,SecretValueFromSource instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new SecretValueFromSource());

    if (instance != null) {
      fluent.withSecretKeyRef(instance.getSecretKeyRef());
      fluent.withSecretKeyRef(instance.getSecretKeyRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  public SecretValueFromSourceBuilder(SecretValueFromSource instance) {
    this(instance,false);
  }
  public SecretValueFromSourceBuilder(SecretValueFromSource instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new SecretValueFromSource());

    if (instance != null) {
      this.withSecretKeyRef(instance.getSecretKeyRef());
      this.withSecretKeyRef(instance.getSecretKeyRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  SecretValueFromSourceFluent<?> fluent;
  Boolean validationEnabled;
  public SecretValueFromSource build() {
    SecretValueFromSource buildable = new SecretValueFromSource(fluent.getSecretKeyRef());
    return buildable;
  }
  
}
